@@ -39,8 +39,9 @@ INPUT(INPUT_SHIFT_WEST,               {"shift-west"},
 INPUT(INPUT_SHIFT_EAST,               {"shift-east"},                               {"."})
 INPUT(INPUT_SHIFT_RESET,              {"shift-reset"},                              {"<"})
 INPUT(INPUT_SORT_BY_TIME,             {"sort-by-time"},                             {"t"})
-INPUT(INPUT_SORT_BY_TIME_UPDATE,      {"sort-by-time-update"},                      {/* not set by default */})
+INPUT(INPUT_SORT_BY_TIME_DOWNLOAD,    {"sort-by-time-download"},                    {/* not set by default */})
 INPUT(INPUT_SORT_BY_TIME_PUBLICATION, {"sort-by-time-publication"},                 {/* not set by default */})
+INPUT(INPUT_SORT_BY_TIME_UPDATE,      {"sort-by-time-update"},                      {/* not set by default */})
 INPUT(INPUT_SORT_BY_ROWID,            {"sort-by-rowid"},                            {"w"})
 INPUT(INPUT_SORT_BY_UNREAD,           {"sort-by-unread"},                           {"u"})
 INPUT(INPUT_SORT_BY_INITIAL,          {"sort-by-initial"},                          {"z"})
@@ -62,7 +63,7 @@ INPUT(INPUT_VIEW_ERRORS,              {"view-errors"},
 INPUT(INPUT_OPEN_IN_BROWSER,          {"open-in-browser"},                          {"o"})
 INPUT(INPUT_COPY_TO_CLIPBOARD,        {"copy-to-clipboard"},                        {"y", "c"})
 INPUT(INPUT_START_SEARCH_INPUT,       {"start-search-input"},                       {"/"})
-INPUT(INPUT_CLEAN_STATUS,             {"clean-status"},                             {"escape"})
+INPUT(INPUT_CLEAN_STATUS,             {"clean-status"},                             {"`"})
 INPUT(INPUT_NAVIGATE_BACK,            {"return", "navigate-back"},                  {"h", "backspace", "KEY_LEFT", "KEY_BACKSPACE"})
 INPUT(INPUT_QUIT_SOFT,                {"quit"},                                     {"q"})
 INPUT(INPUT_QUIT_HARD,                {"quit-hard"},                                {"Q"})
