@@ -27,18 +27,12 @@ bool
 adjust_list_menu(void)
 {
 	INFO("Adjusting list menu.");
-	// Delete old windows to create new windows with the new size.
 	for (size_t i = 0; i < windows_count; ++i) {
 		delwin(windows[i]);
 	}
-	windows = newsraft_realloc(windows, sizeof(WINDOW *) * list_menu_height);
+	windows = newsraft_realloc(windows, sizeof(WINDOW *) * (list_menu_height + 1));
 	for (size_t i = 0; i < list_menu_height; ++i) {
 		windows[i] = newwin(i);
-		if (windows[i] == NULL) {
-			windows_count = i;
-			FAIL("newwin() returned NULL!");
-			return false;
-		}
 	}
 	windows_count = list_menu_height;
 	scrolloff = get_cfg_uint(NULL, CFG_SCROLLOFF);
@@ -67,17 +61,17 @@ list_menu_writer(size_t index, WINDOW *w)
 		if (list_fmtout->len > horizontal_shift) {
 			waddwstr(w, list_fmtout->ptr + horizontal_shift);
 		}
-		struct config_color color = menu->paint_action(menu, index);
-		if (index == menu->view_sel) {
-			color.attributes |= TB_REVERSE;
-		}
-		wbkgd(w, color);
+		wbkgd(w, menu->paint_action(menu, index, index == menu->view_sel));
 	}
 }
 
 static inline void
 expose_entry_of_the_list_menu_unprotected(size_t index)
 {
+	if (index < menu->view_min || (index - menu->view_min) >= windows_count) {
+		WARN("Ignoring list entry expose because of zero size.");
+		return;
+	}
 	WINDOW *w = windows[index - menu->view_min];
 	werase(w);
 	wmove(w, 0);
@@ -118,6 +112,10 @@ expose_all_visible_entries_of_the_list_menu(void)
 void
 redraw_list_menu_unprotected(void)
 {
+	if (list_menu_height < 1) {
+		WARN("Ignoring list view redraw because of zero size.");
+		return;
+	}
 	menu->view_max = menu->view_min + (list_menu_height - 1);
 	if (menu->view_sel > menu->view_max) {
 		menu->view_max = menu->view_sel;
@@ -151,8 +149,23 @@ obtain_list_entries_count_unprotected(struct menu_state *m)
 }
 
 static void
-change_list_view_unprotected(struct menu_state *m, size_t new_sel)
+change_list_view_unprotected(struct menu_state *m, size_t new_sel, bool is_wrappable)
 {
+	if (list_menu_height < 1) {
+		WARN("Ignoring list view change because of zero size.");
+		return;
+	}
+	if (is_wrappable && get_cfg_bool(NULL, CFG_SCROLLWRAP)) {
+		if (new_sel > m->view_sel) {
+			// Tried to go forward
+			if (m->enumerator(m, m->view_sel) && !m->enumerator(m, m->view_sel + 1)) {
+				new_sel = 0;
+			}
+		} else if (new_sel == 0 && m->view_sel == 0) {
+			// Tried to go backward
+			new_sel = obtain_list_entries_count_unprotected(m);
+		}
+	}
 	while (m->enumerator(m, new_sel) == false && new_sel > 0) {
 		new_sel -= 1;
 	}
@@ -188,11 +201,9 @@ change_list_view_unprotected(struct menu_state *m, size_t new_sel)
 		}
 	} else if (new_sel != m->view_sel) {
 		if (m == menu) {
-			wbkgd(windows[m->view_sel - m->view_min], m->paint_action(m, m->view_sel));
+			wbkgd(windows[m->view_sel - m->view_min], m->paint_action(m, m->view_sel, false));
 			m->view_sel = new_sel;
-			struct config_color color = m->paint_action(m, m->view_sel);
-			color.attributes |= TB_REVERSE;
-			wbkgd(windows[m->view_sel - m->view_min], color);
+			wbkgd(windows[m->view_sel - m->view_min], m->paint_action(m, m->view_sel, true));
 			tb_present();
 		} else {
 			m->view_sel = new_sel;
@@ -200,102 +211,79 @@ change_list_view_unprotected(struct menu_state *m, size_t new_sel)
 	}
 }
 
+static void
+change_list_view_filtered_unprotected(struct menu_state *m, bool (*filter)(struct menu_state *, size_t), bool is_forward)
+{
+	if (!filter) {
+		return;
+	}
+	if (is_forward) {
+		for (size_t i = m->view_sel + 1, j = 0; j < 2; i = 0, ++j) {
+			while (m->enumerator(m, i) == true) {
+				if (filter(m, i) == true) {
+					change_list_view_unprotected(m, i, false);
+					j = 2;
+					break;
+				}
+				i += 1;
+			}
+			if (!get_cfg_bool(NULL, CFG_SCROLLWRAP)) {
+				break;
+			}
+		}
+	} else {
+		for (size_t i = m->view_sel, j = 0; j < 2; ++j) {
+			while (i > 0 && m->enumerator(m, i - 1) == true) {
+				if (filter(m, i - 1) == true) {
+					change_list_view_unprotected(m, i - 1, false);
+					j = 2;
+					break;
+				}
+				i -= 1;
+			}
+			if (j < 2) {
+				i = obtain_list_entries_count_unprotected(m);
+			}
+			if (!get_cfg_bool(NULL, CFG_SCROLLWRAP)) {
+				break;
+			}
+		}
+	}
+}
+
 bool
 handle_list_menu_control(struct menu_state *m, input_id cmd, const struct wstring *arg)
 {
 	pthread_mutex_lock(&interface_lock);
 	if (cmd == INPUT_SELECT_NEXT || cmd == INPUT_JUMP_TO_NEXT) {
-		change_list_view_unprotected(m, m->view_sel + 1);
+		change_list_view_unprotected(m, m->view_sel + 1, true);
 	} else if (cmd == INPUT_SELECT_PREV || cmd == INPUT_JUMP_TO_PREV) {
-		change_list_view_unprotected(m, m->view_sel > 1 ? m->view_sel - 1 : 0);
+		change_list_view_unprotected(m, m->view_sel > 1 ? m->view_sel - 1 : 0, true);
 	} else if (cmd == INPUT_JUMP_TO_NEXT_UNREAD) {
-		for (size_t i = m->view_sel + 1, j = 0; j < 2; i = 0, ++j) {
-			while (m->enumerator(m, i) == true) {
-				if (m->unread_state(m, i) == true) {
-					change_list_view_unprotected(m, i);
-					j = 2;
-					break;
-				}
-				i += 1;
-			}
-		}
+		change_list_view_filtered_unprotected(m, m->unread_state, true);
 	} else if (cmd == INPUT_JUMP_TO_PREV_UNREAD) {
-		for (size_t i = m->view_sel, j = 0; j < 2; ++j) {
-			while (i > 0 && m->enumerator(m, i - 1) == true) {
-				if (m->unread_state(m, i - 1) == true) {
-					change_list_view_unprotected(m, i - 1);
-					j = 2;
-					break;
-				}
-				i -= 1;
-			}
-			if (j < 2) {
-				i = obtain_list_entries_count_unprotected(m);
-			}
-		}
+		change_list_view_filtered_unprotected(m, m->unread_state, false);
 	} else if (cmd == INPUT_JUMP_TO_NEXT_IMPORTANT && m->run == &items_menu_loop) {
-		for (size_t i = m->view_sel + 1, j = 0; j < 2; i = 0, ++j) {
-			while (m->enumerator(m, i) == true) {
-				if (important_item_condition(m, i) == true) {
-					change_list_view_unprotected(m, i);
-					j = 2;
-					break;
-				}
-				i += 1;
-			}
-		}
+		change_list_view_filtered_unprotected(m, important_item_condition, true);
 	} else if (cmd == INPUT_JUMP_TO_PREV_IMPORTANT && m->run == &items_menu_loop) {
-		for (size_t i = m->view_sel, j = 0; j < 2; ++j) {
-			while (i > 0 && m->enumerator(m, i - 1) == true) {
-				if (important_item_condition(m, i - 1) == true) {
-					change_list_view_unprotected(m, i - 1);
-					j = 2;
-					break;
-				}
-				i -= 1;
-			}
-			if (j < 2) {
-				i = obtain_list_entries_count_unprotected(m);
-			}
-		}
-	} else if (cmd == INPUT_JUMP_TO_NEXT_ERROR && m->failed_state != NULL) {
-		for (size_t i = m->view_sel + 1, j = 0; j < 2; i = 0, ++j) {
-			while (m->enumerator(m, i) == true) {
-				if (m->failed_state(m, i) == true) {
-					change_list_view_unprotected(m, i);
-					j = 2;
-					break;
-				}
-				i += 1;
-			}
-		}
-	} else if (cmd == INPUT_JUMP_TO_PREV_ERROR && m->failed_state != NULL) {
-		for (size_t i = m->view_sel, j = 0; j < 2; ++j) {
-			while (i > 0 && m->enumerator(m, i - 1) == true) {
-				if (m->failed_state(m, i - 1) == true) {
-					change_list_view_unprotected(m, i - 1);
-					j = 2;
-					break;
-				}
-				i -= 1;
-			}
-			if (j < 2) {
-				i = obtain_list_entries_count_unprotected(m);
-			}
-		}
+		change_list_view_filtered_unprotected(m, important_item_condition, false);
+	} else if (cmd == INPUT_JUMP_TO_NEXT_ERROR) {
+		change_list_view_filtered_unprotected(m, m->failed_state, true);
+	} else if (cmd == INPUT_JUMP_TO_PREV_ERROR) {
+		change_list_view_filtered_unprotected(m, m->failed_state, false);
 	} else if (cmd == INPUT_SELECT_NEXT_PAGE) {
-		change_list_view_unprotected(m, m->view_sel + list_menu_height);
+		change_list_view_unprotected(m, m->view_sel + list_menu_height, true);
 	} else if (cmd == INPUT_SELECT_NEXT_PAGE_HALF) {
-		change_list_view_unprotected(m, m->view_sel + list_menu_height / 2);
+		change_list_view_unprotected(m, m->view_sel + list_menu_height / 2, true);
 	} else if (cmd == INPUT_SELECT_PREV_PAGE) {
-		change_list_view_unprotected(m, m->view_sel > list_menu_height ? m->view_sel - list_menu_height : 0);
+		change_list_view_unprotected(m, m->view_sel > list_menu_height ? m->view_sel - list_menu_height : 0, true);
 	} else if (cmd == INPUT_SELECT_PREV_PAGE_HALF) {
 		size_t step = list_menu_height / 2;
-		change_list_view_unprotected(m, m->view_sel > step ? m->view_sel - step : 0);
+		change_list_view_unprotected(m, m->view_sel > step ? m->view_sel - step : 0, true);
 	} else if (cmd == INPUT_SELECT_FIRST) {
-		change_list_view_unprotected(m, 0);
+		change_list_view_unprotected(m, 0, false);
 	} else if (cmd == INPUT_SELECT_LAST) {
-		change_list_view_unprotected(m, obtain_list_entries_count_unprotected(m));
+		change_list_view_unprotected(m, obtain_list_entries_count_unprotected(m), false);
 	} else if (cmd == INPUT_SHIFT_WEST) {
 		size_t shift_delta = 1 + list_menu_width / 50;
 		if (horizontal_shift >= shift_delta) {
@@ -330,6 +318,10 @@ handle_list_menu_control(struct menu_state *m, input_id cmd, const struct wstrin
 static void
 change_pager_view_unprotected(size_t new_sel)
 {
+	if (list_menu_height < 1) {
+		WARN("Ignoring pager view change because of zero size.");
+		return;
+	}
 	while (menu->enumerator(menu, new_sel) == false && new_sel > 0) {
 		new_sel -= 1;
 	}
@@ -388,6 +380,7 @@ free_deleted_menus(void)
 		struct menu_state *tmp = menus;
 		menus = menus->prev;
 		free_string(tmp->name);
+		free_string(tmp->search_token);
 		free_items_list(tmp->items);
 		newsraft_free(tmp->feeds);
 		newsraft_free(tmp);
@@ -401,6 +394,7 @@ free_menus(void)
 		struct menu_state *tmp = menus;
 		menus = menus->prev;
 		free_string(tmp->name);
+		free_string(tmp->search_token);
 		free_items_list(tmp->items);
 		newsraft_free(tmp->feeds);
 		newsraft_free(tmp);
@@ -432,15 +426,18 @@ setup_menu(struct menu_state *(*run)(struct menu_state *), const struct string *
 {
 	pthread_mutex_lock(&interface_lock);
 	update_unread_items_count_of_last_menu();
-	struct menu_state *new = newsraft_calloc(1, sizeof(struct menu_state));
+	struct menu_state *new = newsraft_calloc(1, sizeof(*new));
 	new->run            = run;
 	new->feeds_original = feeds;
 	new->feeds_count    = feeds_count;
 	new->flags          = flags;
 	new->prev           = menus;
 	new->find_filter    = ctx;
+	new->search_token   = pop_search_filter();
 	if (!STRING_IS_EMPTY(name)) {
 		cpyss(&new->name, name);
+	} else if (!STRING_IS_EMPTY(new->search_token)) {
+		cpyss(&new->name, new->search_token);
 	} else if (new->find_filter) {
 		new->name = convert_wstring_to_string(new->find_filter);
 	} else if (feeds != NULL && feeds_count == 1) {
