@@ -1,4 +1,5 @@
 #include <stdlib.h>
+#include "load_config/load_config.h"
 #include "newsraft.h"
 
 static bool paint_it_black = true;
@@ -10,22 +11,20 @@ static bool
 obtain_list_menu_size(size_t *width, size_t *height)
 {
 	int terminal_width = tb_width();
-	// This is really critical! You will get integer overflow if terminal_width
-	// is less than 12. You have been warned.
-	if (terminal_width < 12) {
-		FAIL("Terminal is too narrow!");
+	if (terminal_width < 0) {
+		FAIL("Terminal width of %d is invalid!", terminal_width);
 		return false;
 	}
 	int terminal_height = tb_height();
-	if (terminal_height < 5) {
-		FAIL("Terminal is too short!");
+	if (terminal_height < 0) {
+		FAIL("Terminal height of %d is invalid!", terminal_height);
 		return false;
 	}
 
 	INFO("Obtained terminal size: %d width, %d height.", terminal_width, terminal_height);
 
 	*width = terminal_width;
-	*height = terminal_height - 1; // Subtract 1 because we have status window.
+	*height = terminal_height > 1 ? terminal_height - 1 : 0; // 1 row is reserved for status window
 
 	return true;
 }
@@ -43,32 +42,43 @@ ui_log_function(const char *fmt, ...)
 bool
 ui_init(void)
 {
+	INFO("Initializing user interface...");
+
 	tb_set_log_function(ui_log_function);
+	// Please, note that tb_init() hides the cursor automatically for us.
 	int status = tb_init();
 	if (status != TB_OK) {
 		write_error("Initialization of user interface failed: %s.\n", tb_strerror(status));
 		return false;
 	}
+	if (is_escape_key_used()) {
+		WARN("Escape key has been bound - engaging ESC input mode!");
+		tb_set_input_mode(TB_INPUT_ESC);
+	} else {
+		INFO("No Escape key binds was found - engaging ALT input mode.");
+		tb_set_input_mode(TB_INPUT_ALT);
+	}
 	if (obtain_list_menu_size(&list_menu_width, &list_menu_height) == false) {
 		write_error("Invalid terminal size obtained!\n");
 		return false;
 	}
-	status = tb_hide_cursor();
-	if (status != TB_OK) {
-		WARN("Can't hide cursor: %s.", tb_strerror(status));
-	}
 	if (!get_cfg_bool(NULL, CFG_IGNORE_NO_COLOR) && getenv("NO_COLOR") != NULL) {
 		INFO("NO_COLOR environment variable is set, canceling colors initialization.");
 	} else {
 		paint_it_black = false; // Some iridescent sensation at last!
+		if (config_uses_256_colors) {
+			tb_set_output_mode(TB_OUTPUT_256);
+		}
 	}
 	newsraft_has_successfully_initialized_ui = true;
 	return true;
 }
 
 void
-ui_stop(void)
+ui_term(void)
 {
+	INFO("Terminating user interface...");
+
 	tb_shutdown();
 }
 
