@@ -1,6 +1,8 @@
 #include <string.h>
 #include "load_config/load_config.h"
 
+bool config_uses_256_colors = false;
+
 bool
 parse_color_setting(struct config_context **ctx, config_entry_id id, const char *iter)
 {
@@ -22,8 +24,9 @@ parse_color_setting(struct config_context **ctx, config_entry_id id, const char
 		else if (strncmp(iter, "underlined", 10) == 0) { attribute |= TB_UNDERLINE;      }
 		else if (strncmp(iter, "italic",      6) == 0) { attribute |= TB_ITALIC;         }
 		else if (strncmp(iter, "color",       5) == 0) {
-			tb_set_output_mode(TB_OUTPUT_256);
-			colors[i] = strtoll(iter + 5, NULL, 10);
+			config_uses_256_colors = true;
+			// TODO: explain why we need this +1 here. That's some nasty stuff
+			colors[i] = strtoll(iter + 5, NULL, 10) + 1;
 			if (colors[i] < 0 || colors[i] > 255) {
 				write_error("Color number must be in the range from 0 to 255!\n");
 				return false;
