@@ -13,7 +13,7 @@
 #include "termbox2.h"
 
 #ifndef NEWSRAFT_VERSION
-#define NEWSRAFT_VERSION "0.32"
+#define NEWSRAFT_VERSION "0.34"
 #endif
 
 #define ISWHITESPACE(A) (((A)==' ')||((A)=='\n')||((A)=='\t')||((A)=='\v')||((A)=='\f')||((A)=='\r'))
@@ -29,10 +29,12 @@
 #define NEWSRAFT_MIN(A, B) (((A) < (B)) ? (A) : (B)) // Need prefix because some platforms have their own MIN definition
 #define NEWSRAFT_UI(CALL) do { if (ui_is_running()) { CALL; } } while (0) // Make CALL only if UI is running
 #define STRING_IS_EMPTY(A) (((A) == NULL) || ((A)->ptr == NULL) || ((A)->len == 0))
+#define NEWSRAFT_ALL_BITS_SET(x, type) ((x) == (type)~(type)0)
 
 typedef uint8_t config_entry_id;
 typedef uint8_t input_id;
 typedef int newsraft_video_t;
+typedef struct WINDOW WINDOW;
 
 enum {
 	FEED_COLUMN_FEED_URL,
@@ -60,6 +62,7 @@ enum {
 	ITEM_COLUMN_ATTACHMENTS,
 	ITEM_COLUMN_PERSONS,
 	ITEM_COLUMN_EXTRAS,
+	ITEM_COLUMN_DOWNLOAD_DATE,
 	ITEM_COLUMN_PUBLICATION_DATE,
 	ITEM_COLUMN_UPDATE_DATE,
 	ITEM_COLUMN_UNREAD,
@@ -77,21 +80,24 @@ enum {
 
 enum {
 	MENU_NORMAL           = 0,
-	MENU_IS_EXPLORE       = 1,  // Tell items menu to use explore mode
-	MENU_SWALLOW          = 2,  // Replace current menu with this menu
-	MENU_DISABLE_SETTINGS = 4,
+	MENU_IS_EXPLORE       = 1, // Tell items menu to use explore mode
+	MENU_IS_SEARCH        = 2, // Identifies items search menu
+	MENU_SWALLOW          = 4, // Replace current menu with this menu
+	MENU_DISABLE_SETTINGS = 8,
 };
 
-typedef uint8_t sorting_method_t;
-enum { // Even is ascending, odd is descending
+typedef enum {
+	// Even is ascending, odd is descending
 	SORT_BY_INITIAL_ASC = 0,
 	SORT_BY_INITIAL_DESC,
 	SORT_BY_TIME_ASC,
 	SORT_BY_TIME_DESC,
-	SORT_BY_TIME_UPDATE_ASC,
-	SORT_BY_TIME_UPDATE_DESC,
+	SORT_BY_TIME_DOWNLOAD_ASC,
+	SORT_BY_TIME_DOWNLOAD_DESC,
 	SORT_BY_TIME_PUBLICATION_ASC,
 	SORT_BY_TIME_PUBLICATION_DESC,
+	SORT_BY_TIME_UPDATE_ASC,
+	SORT_BY_TIME_UPDATE_DESC,
 	SORT_BY_ROWID_ASC,
 	SORT_BY_ROWID_DESC,
 	SORT_BY_UNREAD_ASC,
@@ -101,7 +107,7 @@ enum { // Even is ascending, odd is descending
 	SORT_BY_IMPORTANT_ASC,
 	SORT_BY_IMPORTANT_DESC,
 	SORT_METHODS_COUNT,
-};
+} sorting_method_t;
 
 typedef uint8_t render_block_format;
 enum {
@@ -154,6 +160,7 @@ struct feed_entry {
 	struct string *name;
 	struct string *link; // link to webpage related to this feed
 	int64_t unread_count;
+	int64_t items_count;
 	int64_t update_date; // date of last feed update attempt
 	struct config_context *cfg;
 	struct input_binding *binds;
@@ -178,11 +185,10 @@ struct items_list {
 	sqlite3_stmt *res;
 	struct string *query;
 	struct string *find_filter;
-	struct string *search_filter;
 	struct item_entry *ptr;
 	size_t len;
 	bool finished;
-	int sorting;
+	sorting_method_t sorting;
 	struct feed_entry **feeds; // Just a pointer to parent feeds
 	size_t feeds_count;
 };
@@ -196,13 +202,6 @@ struct format_arg {
 	} value;
 };
 
-typedef struct {
-	int pos_y;
-	size_t offset;
-	struct wstring *content;
-	uintmax_t attrs;
-} WINDOW;
-
 struct menu_state {
 	struct string *name;
 	struct menu_state *(*run)(struct menu_state *); // Function used to start menu
@@ -217,12 +216,13 @@ struct menu_state {
 	size_t view_max;                    // Index of the last visible entry
 	bool is_initialized;
 	bool is_deleted;
+	struct string *search_token;
 	const struct wstring *entry_format;
 	const struct wstring *find_filter;
 	bool (*enumerator)(struct menu_state *ctx, size_t index); // Checks if index is valid
 	void (*printer)(size_t index, WINDOW *w);                 // Prints to list entry
 	const struct format_arg *(*get_args)(struct menu_state *ctx, size_t index);
-	struct config_color (*paint_action)(struct menu_state *ctx, size_t index);
+	struct config_color (*paint_action)(struct menu_state *ctx, size_t index, bool is_selected);
 	bool (*unread_state)(struct menu_state *ctx, size_t index);
 	bool (*failed_state)(struct menu_state *ctx, size_t index);
 	struct menu_state *prev;
@@ -373,7 +373,7 @@ bool refresh_pager_menu(void);
 void do_format(struct wstring *dest, const wchar_t *fmt, const struct format_arg *args);
 
 // See "sorting.c" file for implementation.
-int get_sorting_id(const char *sorting_name);
+sorting_method_t get_sorting_id(const char *sorting_name);
 const char *get_sorting_message(int sorting_id);
 
 // See "items.c" file for implementation.
@@ -383,10 +383,9 @@ void tell_items_menu_to_regenerate(void);
 struct menu_state *items_menu_loop(struct menu_state *dest);
 
 // See "items-list.c" file for implementation.
-struct items_list *create_items_list(struct feed_entry **feeds, size_t feeds_count, const struct wstring *find_filter, const struct items_list *previous_items);
-bool recreate_items_list(struct items_list **items);
-void obtain_items_at_least_up_to_the_given_index(struct items_list *items, size_t index);
-void change_items_list_sorting(struct items_list **items, input_id cmd);
+bool update_menu_item_list(struct menu_state *ctx);
+void obtain_items_at_least_up_to_the_given_index(struct items_list *items, sqlite3_stmt *force_res, size_t index);
+void change_items_list_sorting(struct menu_state *ctx, input_id cmd);
 void free_items_list(struct items_list *items);
 
 // See "items-pager.c" file for implementation.
@@ -446,6 +445,7 @@ bool db_transaction_commit(void);
 bool db_rollback_transaction(void);
 const char *db_error_string(void);
 int db_bind_string(sqlite3_stmt *stmt, int pos, const struct string *str);
+int db_bind_feed_url(sqlite3_stmt *stmt, int pos, const struct string *str);
 int64_t db_get_date_from_feeds_table(const struct string *url, const char *column, size_t column_len);
 struct string *db_get_string_from_feed_table(const struct string *url, const char *column, size_t column_len);
 void db_update_feed_int64(const struct string *url, const char *column_name, int64_t value, bool only_positive);
@@ -461,7 +461,7 @@ bool db_change_unread_status_of_all_items_in_feeds(struct feed_entry **feeds, si
 
 // See "interface.c" file for implementation.
 bool ui_init(void);
-void ui_stop(void);
+void ui_term(void);
 bool ui_is_running(void);
 bool run_menu_loop(void);
 input_id resize_handler(void);
@@ -492,6 +492,7 @@ struct input_binding *create_or_clean_bind(struct input_binding **target, const
 bool attach_action_to_bind(struct input_binding *bind, input_id cmd, const char *arg, size_t arg_len);
 bool assign_default_binds(void);
 input_id get_input_id_by_name(const char *name);
+bool is_escape_key_used(void);
 void free_binds(struct input_binding *target);
 void free_default_binds(void);
 
@@ -553,6 +554,7 @@ bool parse_config_file(void);
 bool get_cfg_bool(struct config_context **ctx, config_entry_id id);
 size_t get_cfg_uint(struct config_context **ctx, config_entry_id id);
 struct config_color get_cfg_color(struct config_context **ctx, config_entry_id id);
+bool is_cfg_color_set(struct config_context **ctx, config_entry_id id);
 const struct string *get_cfg_string(struct config_context **ctx, config_entry_id id);
 const struct wstring *get_cfg_wstring(struct config_context **ctx, config_entry_id id);
 void free_config(void);
