@@ -1,13 +1,6 @@
 #include <string.h>
 #include "newsraft.h"
 
-void
-setup_json_parser(struct feed_update_state *data)
-{
-	cpyas(&data->text, "", 0);
-	data->media_type = MEDIA_TYPE_JSON;
-}
-
 bool
 newsraft_json_parse(struct feed_update_state *data, const char *content, size_t content_size)
 {
@@ -61,7 +54,7 @@ newsraft_json_parse(struct feed_update_state *data, const char *content, size_t
 
 		if (strcmp(path, "$") == 0) {
 			if (strcmp(key, "home_page_url") == 0) {
-				cpyas(&data->feed.url, value, strlen(value));
+				cpyas(&data->feed.link, value, strlen(value));
 			} else if (strcmp(key, "title") == 0) {
 				cpyas(&data->feed.title, value, strlen(value));
 			} else if (strcmp(key, "description") == 0) {
@@ -133,7 +126,7 @@ newsraft_json_parse(struct feed_update_state *data, const char *content, size_t
 				if (strcmp(key, "id") == 0) {
 					cpyas(&data->feed.item->guid, value, strlen(value));
 				} else if (strcmp(key, "url") == 0) {
-					cpyas(&data->feed.item->url, value, strlen(value));
+					cpyas(&data->feed.item->link, value, strlen(value));
 				} else if (strcmp(key, "title") == 0) {
 					cpyas(&data->feed.item->title, value, strlen(value));
 				} else if (strcmp(key, "content_html") == 0) {
