@@ -49,16 +49,25 @@ get_section_args(struct menu_state *ctx, size_t index)
 }
 
 static struct config_color
-paint_section(struct menu_state *ctx, size_t index)
+paint_section(struct menu_state *ctx, size_t index, bool is_selected)
 {
 	(void)ctx;
+	struct config_color color;
 	if (sections_view[index]->has_errors) {
-		return get_cfg_color(NULL, CFG_COLOR_LIST_SECTION_FAILED);
+		color = get_cfg_color(NULL, CFG_COLOR_LIST_SECTION_FAILED);
 	} else if (sections_view[index]->unread_count > 0) {
-		return get_cfg_color(NULL, CFG_COLOR_LIST_SECTION_UNREAD);
+		color = get_cfg_color(NULL, CFG_COLOR_LIST_SECTION_UNREAD);
 	} else {
-		return get_cfg_color(NULL, CFG_COLOR_LIST_SECTION);
+		color = get_cfg_color(NULL, CFG_COLOR_LIST_SECTION);
 	}
+	if (is_selected) {
+		if (is_cfg_color_set(NULL, CFG_COLOR_LIST_SECTION_SELECTED)) {
+			color = get_cfg_color(NULL, CFG_COLOR_LIST_SECTION_SELECTED);
+		} else {
+			color.attributes |= TB_REVERSE;
+		}
+	}
+	return color;
 }
 
 static bool
@@ -225,7 +234,7 @@ purge_abandoned_feeds(void)
 		return false;
 	}
 	for (size_t i = 0; i < sections[0].feeds_count; ++i) {
-		db_bind_string(res, i + 1, sections[0].feeds[i]->url);
+		db_bind_feed_url(res, i + 1, sections[0].feeds[i]->url);
 	}
 	bool status = sqlite3_step(res) == SQLITE_DONE ? true : false;
 	sqlite3_finalize(res);
@@ -382,7 +391,7 @@ sections_menu_loop(struct menu_state *m)
 			case INPUT_TOGGLE_EXPLORE_MODE:
 				return setup_menu(&items_menu_loop, NULL, sections[0].feeds, sections[0].feeds_count, MENU_IS_EXPLORE, NULL);
 			case INPUT_APPLY_SEARCH_MODE_FILTER:
-				return setup_menu(&items_menu_loop, NULL, sections[0].feeds, sections[0].feeds_count, MENU_IS_EXPLORE, NULL);
+				return setup_menu(&items_menu_loop, NULL, sections[0].feeds, sections[0].feeds_count, MENU_IS_SEARCH | MENU_IS_EXPLORE, NULL);
 			case INPUT_VIEW_ERRORS:
 				return setup_menu(&errors_pager_loop, NULL, sections_view[m->view_sel]->feeds, sections_view[m->view_sel]->feeds_count, MENU_NORMAL, NULL);
 			case INPUT_SORT_BY_UNREAD:
